@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 
 import codecs
 import glob
@@ -6,17 +7,18 @@ import pprint
 import re
 import shutil
 import sys
+import json
 try:
     import cPickle as pickle
 except ImportError:  # PY3
     import pickle as pickle
 from optparse import OptionParser
 
-from Cheetah.Compiler import DEFAULT_COMPILER_SETTINGS
-from Cheetah.Template import Template
-from Cheetah.Utils.Misc import mkdirsWithPyInitFiles
-from Cheetah.Version import Version
-from Cheetah.compat import PY2
+from .Compiler import DEFAULT_COMPILER_SETTINGS
+from .Template import Template
+from .Utils.Misc import mkdirsWithPyInitFiles
+from .Version import Version
+from .compat import PY2
 
 optionDashesRE = re.compile(R"^-{1,2}")
 moduleNameRE = re.compile(R"^[a-zA-Z_][a-zA-Z_0-9]*$")
@@ -65,7 +67,7 @@ def usage(usageMessage, errorMessage="", out=sys.stderr):
     sys.exit(exitStatus)
 
 
-WRAPPER_TOP = """\
+WRAPPER_TOP = r"""\
          __  ____________  __
          \ \/            \/ /
           \/    *   *     \/    CHEETAH %(Version)s Command-Line Tool
@@ -176,6 +178,8 @@ class CheetahWrapper(object):
             help='Pass the environment into the search list')
         pao("--pickle", action="store", dest="pickle", default="",
             help='Unpickle FILE and pass it through in the search list')
+        pao("--json", action="store", dest="json", default="",
+            help='Read from JSON FILE and pass it through in the search list')
         pao("--flat", action="store_true", dest="flat", default=False,
             help='Do not build destination subdirectories')
         pao("--nobackup", action="store_true", dest="nobackup", default=False,
@@ -223,12 +227,12 @@ Files are %s""", args, pprint.pformat(vars(opts)), files)
         if opts.print_settings:
             print()
             print('>> Available Cheetah compiler settings:')
-            from Cheetah.Compiler import _DEFAULT_COMPILER_SETTINGS
+            from .Compiler import _DEFAULT_COMPILER_SETTINGS
             listing = _DEFAULT_COMPILER_SETTINGS
-            listing.sort(key=lambda l: l[0][0].lower())
+            listing.sort(key=lambda _l: _l[0][0].lower())
 
-            for l in listing:
-                print('\t%s (default: "%s")\t%s' % l)
+            for _l in listing:
+                print('\t%s (default: "%s")\t%s' % _l)
             sys.exit(0)
 
         # cleanup trailing path separators
@@ -249,6 +253,11 @@ Files are %s""", args, pprint.pformat(vars(opts)), files)
             unpickled = pickle.load(f)
             f.close()
             self.searchList.insert(0, unpickled)
+        if opts.json:
+            f = open(opts.json, 'r')
+            unjsoned = json.load(f)
+            f.close()
+            self.searchList.insert(0, unjsoned)
 
     ##################################################
     # COMMAND METHODS
@@ -257,7 +266,7 @@ Files are %s""", args, pprint.pformat(vars(opts)), files)
         self._compileOrFill()
 
     def fill(self):
-        from Cheetah.ImportHooks import install
+        from .ImportHooks import install
         install()
         self._compileOrFill()
 
@@ -281,15 +290,14 @@ you do have write permission to and re-run the tests.""")
             f.close()
             os.remove(TEST_WRITE_FILENAME)
         # @@MO: End ugly kludge.
-        from Cheetah.Tests import Test
         import unittest
+        from .Tests import Test
         verbosity = 1
         if '-q' in self.testOpts:
             verbosity = 0
         if '-v' in self.testOpts:
             verbosity = 2
         runner = unittest.TextTestRunner(verbosity=verbosity)
-        runner.run(unittest.TestSuite(Test.suites))
         results = runner.run(unittest.TestSuite(Test.suites))
         exit(int(not results.wasSuccessful()))
 
@@ -321,7 +329,8 @@ you do have write permission to and re-run the tests.""")
         fprintfMessage(sys.stderr, format, *args)
 
     def error(self, format, *args):
-        """Always print a warning message to stderr and exit with an error code.
+        """
+        Always print a warning message to stderr and exit with an error code.
         """
         fprintfMessage(sys.stderr, format, *args)
         sys.exit(1)
@@ -457,8 +466,8 @@ you do have write permission to and re-run the tests.""")
                     raise Error("source file '%s' is a directory" % path)
             elif os.path.isfile(path):
                 files.append(path)
-            elif (addIextIfMissing and not path.endswith(iext) and
-                  os.path.isfile(pathWithExt)):
+            elif (addIextIfMissing and not path.endswith(iext)
+                    and os.path.isfile(pathWithExt)):
                 files.append(pathWithExt)
                 # Do not recurse directories discovered by iext appending.
             elif os.path.exists(path):
@@ -531,8 +540,8 @@ you do have write permission to and re-run the tests.""")
 
         if p >= 0:
             mod = getattr(
-                __import__(modname[:p], {}, {}, [modname[p+1:]]),
-                modname[p+1:])
+                __import__(modname[:p], {}, {}, [modname[p+1:]]),  # noqa: E226,E501 missing whitespace around operator
+                modname[p+1:])  # noqa: E226 missing whitespace around operator
         else:
             mod = __import__(modname, {}, {}, [])
 
@@ -583,7 +592,7 @@ you do have write permission to and re-run the tests.""")
             pysrc = TemplateClass.compile(file=sys.stdin,
                                           compilerSettings=compilerSettings,
                                           returnAClass=False)
-            output = pysrc
+            output = pysrc if PY2 else pysrc.decode()
         else:
             output = str(TemplateClass(file=sys.stdin,
                                        compilerSettings=compilerSettings))
