@@ -12,6 +12,11 @@ else:
     string_type = str
     unicode = str
 
+try:
+    ModuleNotFoundError = ModuleNotFoundError
+except NameError:  # Python 2.7, 3.4, 3.5
+    ModuleNotFoundError = ImportError
+
 try:
     RecursionError = RecursionError
 except NameError:  # Python 2.7, 3.4
@@ -32,6 +37,16 @@ if PY2:
     new_module = imp.new_module
     get_suffixes = imp.get_suffixes
 
+    def cache_from_source(path, debug_override=None):
+        assert path.endswith('.py'), path
+        if debug_override is None:
+            debug_override = __debug__
+        if debug_override:
+            suffix = 'c'
+        else:
+            suffix = 'o'
+        return path + suffix
+
 else:
     import importlib.machinery
     import importlib.util
@@ -47,10 +62,12 @@ else:
             (s, 'rb', 3) for s in importlib.machinery.EXTENSION_SUFFIXES
         ]
         source = [
-            (s, 'rU', 1) for s in importlib.machinery.SOURCE_SUFFIXES
+            (s, 'r', 1) for s in importlib.machinery.SOURCE_SUFFIXES
         ]
         bytecode = [
             (s, 'rb', 2) for s in importlib.machinery.BYTECODE_SUFFIXES
         ]
 
         return extensions + source + bytecode
+
+    from importlib.util import cache_from_source  # noqa: F401 unused
